@@ -1,8 +1,8 @@
 /*
 **  OSSP sa - Socket Abstraction
-**  Copyright (c) 2001-2002 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2001-2002 The OSSP Project <http://www.ossp.org/>
-**  Copyright (c) 2001-2002 Cable & Wireless Deutschland <http://www.cw.com/de/>
+**  Copyright (c) 2001-2003 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2001-2003 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2001-2003 Cable & Wireless Deutschland <http://www.cw.com/de/>
 **
 **  This file is part of OSSP sa, a socket abstraction library which
 **  can be found at http://www.ossp.org/pkg/lib/sa/.
@@ -42,7 +42,7 @@
 #include "l2_config.h"
 
 /* fallback for POSIX socklen_t */
-#if defined(HAVE_CONFIG_H) && !defined(HAVE_SOCKLEN_T)
+#if !defined(HAVE_SOCKLEN_T)
 typedef int socklen_t;
 #endif
 
@@ -89,6 +89,8 @@ typedef int socklen_t;
 #define sa_flush        SA_CONCAT(SA_PREFIX,sa_flush)
 #define sa_recv         SA_CONCAT(SA_PREFIX,sa_recv)
 #define sa_send         SA_CONCAT(SA_PREFIX,sa_send)
+#define sa_sendf        SA_CONCAT(SA_PREFIX,sa_sendf)
+#define sa_id           SA_CONCAT(SA_PREFIX,sa_id)
 #define sa_error        SA_CONCAT(SA_PREFIX,sa_error)
 #endif
 
@@ -137,11 +139,11 @@ typedef enum {
 
 /* list of options */
 typedef enum {
-    SA_OPTION_NAGLE,
-    SA_OPTION_LINGER,
-    SA_OPTION_REUSEADDR,
-    SA_OPTION_REUSEPORT,
-    SA_OPTION_NONBLOCK
+    SA_OPTION_NAGLE     = 0,
+    SA_OPTION_LINGER    = 1,
+    SA_OPTION_REUSEADDR = 2,
+    SA_OPTION_REUSEPORT = 3,
+    SA_OPTION_NONBLOCK  = 4
 } sa_option_t;
 
 /* list of system calls */
@@ -159,50 +161,51 @@ typedef enum {
 extern const char sa_id[];
 
 /* address object operations */
-sa_rc_t sa_addr_create  (sa_addr_t **saa);
-sa_rc_t sa_addr_destroy (sa_addr_t *saa);
+extern sa_rc_t sa_addr_create  (sa_addr_t **__saa);
+extern sa_rc_t sa_addr_destroy (sa_addr_t  *__saa);
 
 /* address operations */
-sa_rc_t sa_addr_u2a     (sa_addr_t *saa, const char *uri, ...);
-sa_rc_t sa_addr_s2a     (sa_addr_t *saa, const struct sockaddr *sabuf, socklen_t salen);
-sa_rc_t sa_addr_a2u     (sa_addr_t *saa, char **uri);
-sa_rc_t sa_addr_a2s     (sa_addr_t *saa, struct sockaddr **sabuf, socklen_t *salen);
-sa_rc_t sa_addr_match   (sa_addr_t *saa1, sa_addr_t *saa2, int prefixlen);
+extern sa_rc_t sa_addr_u2a     (sa_addr_t  *__saa, const char *__uri, ...);
+extern sa_rc_t sa_addr_s2a     (sa_addr_t  *__saa, const struct sockaddr *__sabuf, socklen_t __salen);
+extern sa_rc_t sa_addr_a2u     (sa_addr_t  *__saa, char **__uri);
+extern sa_rc_t sa_addr_a2s     (sa_addr_t  *__saa, struct sockaddr **__sabuf, socklen_t *__salen);
+extern sa_rc_t sa_addr_match   (sa_addr_t  *__saa1, sa_addr_t *__saa2, int __prefixlen);
 
 /* socket object operations */
-sa_rc_t sa_create       (sa_t **sa);
-sa_rc_t sa_destroy      (sa_t *sa);
+extern sa_rc_t sa_create       (sa_t **__sa);
+extern sa_rc_t sa_destroy      (sa_t  *__sa);
 
 /* socket parameter operations */
-sa_rc_t sa_type         (sa_t *sa, sa_type_t type);
-sa_rc_t sa_timeout      (sa_t *sa, sa_timeout_t id, long sec, long usec);
-sa_rc_t sa_buffer       (sa_t *sa, sa_buffer_t  id, size_t size);
-sa_rc_t sa_option       (sa_t *sa, sa_option_t  id, ...);
-sa_rc_t sa_syscall      (sa_t *sa, sa_syscall_t id, void (*fptr)(), void *fctx);
+extern sa_rc_t sa_type         (sa_t  *__sa, sa_type_t    __id);
+extern sa_rc_t sa_timeout      (sa_t  *__sa, sa_timeout_t __id, long __sec, long __usec);
+extern sa_rc_t sa_buffer       (sa_t  *__sa, sa_buffer_t  __id, size_t __size);
+extern sa_rc_t sa_option       (sa_t  *__sa, sa_option_t  __id, ...);
+extern sa_rc_t sa_syscall      (sa_t  *__sa, sa_syscall_t __id, void (*__fptr)(void), void *__fctx);
 
 /* socket connection operations */
-sa_rc_t sa_bind         (sa_t *sa, sa_addr_t *laddr);
-sa_rc_t sa_connect      (sa_t *sa, sa_addr_t *raddr);
-sa_rc_t sa_listen       (sa_t *sa, int backlog);
-sa_rc_t sa_accept       (sa_t *sa, sa_addr_t **caddr, sa_t **csa);
-sa_rc_t sa_getremote    (sa_t *sa, sa_addr_t **raddr);
-sa_rc_t sa_getlocal     (sa_t *sa, sa_addr_t **laddr);
-sa_rc_t sa_getfd        (sa_t *sa, int *fd);
-sa_rc_t sa_shutdown     (sa_t *sa, char *flags);
+extern sa_rc_t sa_bind         (sa_t  *__sa, sa_addr_t  *__laddr);
+extern sa_rc_t sa_connect      (sa_t  *__sa, sa_addr_t  *__raddr);
+extern sa_rc_t sa_listen       (sa_t  *__sa, int __backlog);
+extern sa_rc_t sa_accept       (sa_t  *__sa, sa_addr_t **__caddr, sa_t **__csa);
+extern sa_rc_t sa_getremote    (sa_t  *__sa, sa_addr_t **__raddr);
+extern sa_rc_t sa_getlocal     (sa_t  *__sa, sa_addr_t **__laddr);
+extern sa_rc_t sa_getfd        (sa_t  *__sa, int *__fd);
+extern sa_rc_t sa_shutdown     (sa_t  *__sa, char *__flags);
 
 /* socket input/output operations (stream communication) */
-sa_rc_t sa_read         (sa_t *sa, char *buf, size_t buflen, size_t *bufdone);
-sa_rc_t sa_readln       (sa_t *sa, char *buf, size_t buflen, size_t *bufdone);
-sa_rc_t sa_write        (sa_t *sa, const char *buf, size_t buflen, size_t *bufdone);
-sa_rc_t sa_writef       (sa_t *sa, const char *fmt, ...);
-sa_rc_t sa_flush        (sa_t *sa);
+extern sa_rc_t sa_read         (sa_t  *__sa, char       *__buf, size_t __buflen, size_t *__bufdone);
+extern sa_rc_t sa_readln       (sa_t  *__sa, char       *__buf, size_t __buflen, size_t *__bufdone);
+extern sa_rc_t sa_write        (sa_t  *__sa, const char *__buf, size_t __buflen, size_t *__bufdone);
+extern sa_rc_t sa_writef       (sa_t  *__sa, const char *__fmt, ...);
+extern sa_rc_t sa_flush        (sa_t  *__sa);
 
 /* socket input/output operations (datagram communication) */
-sa_rc_t sa_recv         (sa_t *sa, char *buf, size_t buflen, size_t *bufdone, sa_addr_t **raddr);
-sa_rc_t sa_send         (sa_t *sa, const char *buf, size_t buflen, size_t *bufdone, sa_addr_t *raddr);
+extern sa_rc_t sa_recv         (sa_t  *__sa, sa_addr_t **__raddr, char       *__buf, size_t __buflen, size_t *__bufdone);
+extern sa_rc_t sa_send         (sa_t  *__sa, sa_addr_t  *__raddr, const char *__buf, size_t __buflen, size_t *__bufdone);
+extern sa_rc_t sa_sendf        (sa_t  *__sa, sa_addr_t  *__raddr, const char *__fmt, ...);
 
 /* error handling operations */
-char   *sa_error        (sa_rc_t rv);
+extern char   *sa_error        (sa_rc_t __rv);
 
 /* cleanup */
 #if defined(HAVE_CONFIG_H) && !defined(HAVE_SOCKLEN_T)
